@@ -24,7 +24,7 @@ class AdInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Spots: 插播广告列表
         :type Spots: list of PluginInfo
         :param BoutiqueRecommands: 精品推荐广告列表
@@ -98,7 +98,7 @@ class AppDetailInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppName: app的名称
         :type AppName: str
         :param AppPkgName: app的包名
@@ -146,7 +146,7 @@ class AppInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppUrl: app的url，必须保证不用权限校验就可以下载
         :type AppUrl: str
         :param AppMd5: app的md5，需要正确传递
@@ -198,7 +198,7 @@ class AppScanSet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemId: 任务唯一标识
         :type ItemId: str
         :param AppName: app的名称
@@ -270,7 +270,7 @@ class AppSetInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemId: 任务唯一标识
         :type ItemId: str
         :param AppName: app的名称
@@ -350,7 +350,7 @@ class BindInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppIconUrl: app的icon的url
         :type AppIconUrl: str
         :param AppName: app的名称
@@ -382,7 +382,7 @@ class CreateBindInstanceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源id，全局唯一
         :type ResourceId: str
         :param AppIconUrl: app的icon的url
@@ -418,7 +418,7 @@ class CreateBindInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
         :type Progress: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -439,7 +439,7 @@ class CreateCosSecKeyInstanceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CosRegion: 地域信息，例如广州：ap-guangzhou，上海：ap-shanghai，默认为广州。
         :type CosRegion: str
         :param Duration: 密钥有效时间，默认为1小时。
@@ -467,7 +467,7 @@ class CreateCosSecKeyInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CosAppid: COS密钥对应的AppId
         :type CosAppid: int
         :param CosBucket: COS密钥对应的存储桶名
@@ -516,7 +516,7 @@ class CreateResourceInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Pid: 资源类型id。13624：加固专业版。
         :type Pid: int
         :param TimeUnit: 时间单位，取值为d，m，y，分别表示天，月，年。
@@ -552,7 +552,7 @@ class CreateResourceInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceSet: 新创建的资源列表。
         :type ResourceSet: list of str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -573,7 +573,7 @@ class CreateScanInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppInfos: 待扫描的app信息列表，一次最多提交20个
         :type AppInfos: list of AppInfo
         :param ScanInfo: 扫描信息
@@ -608,7 +608,7 @@ class CreateScanInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemId: 任务唯一标识
         :type ItemId: str
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
@@ -645,7 +645,7 @@ class CreateShieldInstanceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppInfo: 待加固的应用信息
         :type AppInfo: :class:`tencentcloud.ms.v20180408.models.AppInfo`
         :param ServiceInfo: 加固服务信息
@@ -677,7 +677,7 @@ class CreateShieldInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
         :type Progress: int
         :param ItemId: 任务唯一标识
@@ -702,7 +702,7 @@ class CreateShieldPlanInstanceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源id
         :type ResourceId: str
         :param PlanName: 策略名称
@@ -736,7 +736,7 @@ class CreateShieldPlanInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PlanId: 策略id
         :type PlanId: int
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
@@ -761,7 +761,7 @@ class DeleteScanInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppSids: 删除一个或多个扫描的app，最大支持20个
         :type AppSids: list of str
         """
@@ -785,7 +785,7 @@ class DeleteScanInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
         :type Progress: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -806,7 +806,7 @@ class DeleteShieldInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemIds: 任务唯一标识ItemId的列表
         :type ItemIds: list of str
         """
@@ -830,7 +830,7 @@ class DeleteShieldInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
         :type Progress: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -845,36 +845,97 @@ class DeleteShieldInstancesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeApkDetectionResultRequest(AbstractModel):
+    """DescribeApkDetectionResult请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ApkUrl: 软件包的下载链接
+        :type ApkUrl: str
+        :param ApkMd5: 软件包的md5值，具有唯一性。腾讯APK云检测服务会根据md5值来判断该包是否为库中已收集的样本，已存在，则返回检测结果，反之，需要一定时间检测该样本。
+        :type ApkMd5: str
+        """
+        self.ApkUrl = None
+        self.ApkMd5 = None
+
+
+    def _deserialize(self, params):
+        self.ApkUrl = params.get("ApkUrl")
+        self.ApkMd5 = params.get("ApkMd5")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeApkDetectionResultResponse(AbstractModel):
+    """DescribeApkDetectionResult返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Result: 响应结果，ok表示正常，error表示错误
+        :type Result: str
+        :param Reason: Result为error错误时的原因说明
+        :type Reason: str
+        :param ResultList: APK检测结果数组
+        :type ResultList: list of ResultListItem
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Result = None
+        self.Reason = None
+        self.ResultList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Result = params.get("Result")
+        self.Reason = params.get("Reason")
+        if params.get("ResultList") is not None:
+            self.ResultList = []
+            for item in params.get("ResultList"):
+                obj = ResultListItem()
+                obj._deserialize(item)
+                self.ResultList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeResourceInstancesRequest(AbstractModel):
     """DescribeResourceInstances请求参数结构体
 
     """
 
     def __init__(self):
-        """
-        :param Pids: 资源类别id数组，13624：加固专业版，12750：企业版。空数组表示返回全部资源。
-        :type Pids: list of int non-negative
-        :param Filters: 支持通过资源id，pid进行查询
+        r"""
+        :param Filters: 支持CreateTime、ExpireTime、AppName、AppPkgName、BindValue、IsBind过滤
         :type Filters: list of Filter
         :param Offset: 偏移量，默认为0
         :type Offset: int
         :param Limit: 数量限制，默认为20，最大值为100。
         :type Limit: int
+        :param Pids: 资源类别id数组，13624：加固专业版，12750：企业版。空数组表示返回全部资源。
+        :type Pids: list of int non-negative
         :param OrderField: 按某个字段排序，目前支持CreateTime、ExpireTime其中的一个排序。
         :type OrderField: str
         :param OrderDirection: 升序（asc）还是降序（desc），默认：desc。
         :type OrderDirection: str
         """
-        self.Pids = None
         self.Filters = None
         self.Offset = None
         self.Limit = None
+        self.Pids = None
         self.OrderField = None
         self.OrderDirection = None
 
 
     def _deserialize(self, params):
-        self.Pids = params.get("Pids")
         if params.get("Filters") is not None:
             self.Filters = []
             for item in params.get("Filters"):
@@ -883,6 +944,7 @@ class DescribeResourceInstancesRequest(AbstractModel):
                 self.Filters.append(obj)
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        self.Pids = params.get("Pids")
         self.OrderField = params.get("OrderField")
         self.OrderDirection = params.get("OrderDirection")
         memeber_set = set(params.keys())
@@ -900,7 +962,7 @@ class DescribeResourceInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合要求的资源数量
         :type TotalCount: int
         :param ResourceSet: 符合要求的资源数组
@@ -930,7 +992,7 @@ class DescribeScanInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Filters: 支持通过app名称，app包名进行筛选
         :type Filters: list of Filter
         :param Offset: 偏移量，默认为0
@@ -979,7 +1041,7 @@ class DescribeScanInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合要求的app数量
         :type TotalCount: int
         :param ScanSet: 一个关于app详细信息的结构体，主要包括app的基本信息和扫描状态信息。
@@ -1009,7 +1071,7 @@ class DescribeScanResultsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemId: 任务唯一标识
         :type ItemId: str
         :param AppMd5s: 批量查询一个或者多个app的扫描结果，如果不传表示查询该任务下所提交的所有app
@@ -1037,7 +1099,7 @@ class DescribeScanResultsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ScanSet: 批量扫描的app结果集
         :type ScanSet: list of ScanSetInfo
         :param TotalCount: 批量扫描结果的个数
@@ -1067,7 +1129,7 @@ class DescribeShieldInstancesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Filters: 支持通过app名称，app包名，加固的服务版本，提交的渠道进行筛选。
         :type Filters: list of Filter
         :param Offset: 偏移量，默认为0。
@@ -1116,7 +1178,7 @@ class DescribeShieldInstancesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合要求的app数量
         :type TotalCount: int
         :param AppSet: 一个关于app详细信息的结构体，主要包括app的基本信息和加固信息。
@@ -1146,7 +1208,7 @@ class DescribeShieldPlanInstanceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 资源id
         :type ResourceId: str
         :param Pid: 服务类别id
@@ -1174,7 +1236,7 @@ class DescribeShieldPlanInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BindInfo: 绑定资源信息
         :type BindInfo: :class:`tencentcloud.ms.v20180408.models.BindInfo`
         :param ShieldPlanInfo: 加固策略信息
@@ -1209,7 +1271,7 @@ class DescribeShieldResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ItemId: 任务唯一标识
         :type ItemId: str
         """
@@ -1233,7 +1295,7 @@ class DescribeShieldResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskStatus: 任务状态: 0-请返回,1-已完成,2-处理中,3-处理出错,4-处理超时
         :type TaskStatus: int
         :param AppDetailInfo: app加固前的详细信息
@@ -1268,6 +1330,99 @@ class DescribeShieldResultResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeUrlDetectionResultRequest(AbstractModel):
+    """DescribeUrlDetectionResult请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Url: 查询的网址
+        :type Url: str
+        """
+        self.Url = None
+
+
+    def _deserialize(self, params):
+        self.Url = params.get("Url")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeUrlDetectionResultResponse(AbstractModel):
+    """DescribeUrlDetectionResult返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ResultCode: [查询结果]查询结果；枚举值：0 查询成功，否则查询失败
+        :type ResultCode: int
+        :param RespVer: [固定信息]响应协议版本号；
+        :type RespVer: int
+        :param UrlType: [查询结果]url恶意状态；枚举值：1-灰， 2-黑（具体的恶意类型参考恶意类型定义Eviltype字段) ，3-非腾讯白名单，4-腾讯白名单。查询结果（level、evilclass、eviltype）这3个字段在Urltype=2（url状态为黑）下才有意义。
+        :type UrlType: int
+        :param EvilClass: [查询结果]url恶意大类；枚举值：1-链接，2-Cgi，3-路劲，4-整站，5-整域。
+        :type EvilClass: int
+        :param EvilType: [查询结果]url恶意类型；枚举值：1-社工欺诈（仿冒、账号钓鱼、中奖诈骗）；2-信息诈骗（虚假充值、虚假兼职、虚假金融投资、虚假信用卡代办、网络赌博诈骗；3-虚假销售（男女保健美容减肥产品、电子产品、虚假广告、违法销售）；4-恶意文件（病毒文件，木马文件，恶意apk文件的下载链接以及站点，挂马网站）；5-博彩网站（博彩网站，在线赌博网站）；6-色情网站（涉嫌传播色情内容，提供色情服务的网站；7-风险网站（弱类型，传播垃圾信息的网站, 如果客户端有阻断，不建议使用这个数据）；8-非法内容（根据法律法规不能传播的内容，主要为政治敏感内容，默认内部使用）
+        :type EvilType: int
+        :param Level: [查询结果]url恶意级别
+        :type Level: int
+        :param DetectTime: [查询详情]url检出时间
+        :type DetectTime: int
+        :param Wording: [查询详情]拦截Wording
+        :type Wording: str
+        :param WordingTitle: [查询详情]拦截Wording 标题
+        :type WordingTitle: str
+        :param UrlTypeDesc: [查询结果]url恶意状态说明
+        :type UrlTypeDesc: str
+        :param EvilClassDesc: [查询结果]url恶意大类说明
+        :type EvilClassDesc: str
+        :param EvilTypeDesc: [查询结果]url恶意类型说明
+        :type EvilTypeDesc: str
+        :param LevelDesc: [查询结果]url恶意级别说明
+        :type LevelDesc: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ResultCode = None
+        self.RespVer = None
+        self.UrlType = None
+        self.EvilClass = None
+        self.EvilType = None
+        self.Level = None
+        self.DetectTime = None
+        self.Wording = None
+        self.WordingTitle = None
+        self.UrlTypeDesc = None
+        self.EvilClassDesc = None
+        self.EvilTypeDesc = None
+        self.LevelDesc = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ResultCode = params.get("ResultCode")
+        self.RespVer = params.get("RespVer")
+        self.UrlType = params.get("UrlType")
+        self.EvilClass = params.get("EvilClass")
+        self.EvilType = params.get("EvilType")
+        self.Level = params.get("Level")
+        self.DetectTime = params.get("DetectTime")
+        self.Wording = params.get("Wording")
+        self.WordingTitle = params.get("WordingTitle")
+        self.UrlTypeDesc = params.get("UrlTypeDesc")
+        self.EvilClassDesc = params.get("EvilClassDesc")
+        self.EvilTypeDesc = params.get("EvilTypeDesc")
+        self.LevelDesc = params.get("LevelDesc")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeUserBaseInfoInstanceRequest(AbstractModel):
     """DescribeUserBaseInfoInstance请求参数结构体
 
@@ -1280,7 +1435,7 @@ class DescribeUserBaseInfoInstanceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserUin: 用户uin信息
         :type UserUin: int
         :param UserAppid: 用户APPID信息
@@ -1309,7 +1464,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 需要过滤的字段
         :type Name: str
         :param Value: 需要过滤字段的值
@@ -1331,13 +1486,45 @@ class Filter(AbstractModel):
         
 
 
+class OptPluginListItem(AbstractModel):
+    """APK检测服务：非广告插件结果列表(SDK、风险插件等)
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PluginType: 非广告类型
+        :type PluginType: str
+        :param PluginName: 非广告插件名称
+        :type PluginName: str
+        :param PluginDesc: 非广告插件描述
+        :type PluginDesc: str
+        """
+        self.PluginType = None
+        self.PluginName = None
+        self.PluginDesc = None
+
+
+    def _deserialize(self, params):
+        self.PluginType = params.get("PluginType")
+        self.PluginName = params.get("PluginName")
+        self.PluginDesc = params.get("PluginDesc")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class PlanDetailInfo(AbstractModel):
     """加固策略具体信息
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsDefault: 默认策略，1为默认，0为非默认
         :type IsDefault: int
         :param PlanId: 策略id
@@ -1375,7 +1562,7 @@ class PlanInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ApkSizeOpt: apk大小优化，0关闭，1开启
         :type ApkSizeOpt: int
         :param Dex: Dex加固，0关闭，1开启
@@ -1461,7 +1648,7 @@ class PluginInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PluginType: 插件类型，分别为 1-通知栏广告，2-积分墙广告，3-banner广告，4- 悬浮窗图标广告，5-精品推荐列表广告, 6-插播广告
         :type PluginType: int
         :param PluginName: 插件名称
@@ -1487,13 +1674,45 @@ class PluginInfo(AbstractModel):
         
 
 
+class PluginListItem(AbstractModel):
+    """APK检测服务：广告插件结果结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PluginType: 数字类型，分别为 1-通知栏广告，2-积分墙广告，3-banner广告，4- 悬浮窗图标广告，5-精品推荐列表广告, 6-插播广告
+        :type PluginType: str
+        :param PluginName: 广告插件名称
+        :type PluginName: str
+        :param PluginDesc: 广告插件描述
+        :type PluginDesc: str
+        """
+        self.PluginType = None
+        self.PluginName = None
+        self.PluginDesc = None
+
+
+    def _deserialize(self, params):
+        self.PluginType = params.get("PluginType")
+        self.PluginName = params.get("PluginName")
+        self.PluginDesc = params.get("PluginDesc")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ResourceInfo(AbstractModel):
     """拉取某个用户的所有资源信息
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param ResourceId: 用户购买的资源id，全局唯一
         :type ResourceId: str
         :param Pid: 资源的pid，MTP加固-12767，应用加固-12750 MTP反作弊-12766 源代码混淆-12736
@@ -1543,7 +1762,7 @@ class ResourceServiceInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CreateTime: 创建时间戳
         :type CreateTime: int
         :param ExpireTime: 到期时间戳
@@ -1569,13 +1788,137 @@ class ResourceServiceInfo(AbstractModel):
         
 
 
+class ResultListItem(AbstractModel):
+    """APK检测服务参数返回具体信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Banner: banner广告软件标记，分别为-1-不确定，0-否，1-是
+        :type Banner: str
+        :param BoutiqueRecommand: 精品推荐列表广告标记，分别为-1-不确定，0-否，1-是
+        :type BoutiqueRecommand: str
+        :param FloatWindows: 悬浮窗图标广告标记,分别为-1-不确定，0-否，1-是
+        :type FloatWindows: str
+        :param IntegralWall: 积分墙广告软件标记，分别为 -1 -不确定，0-否，1-是
+        :type IntegralWall: str
+        :param Md5: 安装包的md5
+        :type Md5: str
+        :param NotifyBar: 通知栏广告软件标记，分别为-1-不确定，0-否，1-是
+        :type NotifyBar: str
+        :param Official: 1表示官方，0表示非官方
+        :type Official: str
+        :param PluginList: 广告插件结果列表
+        :type PluginList: list of PluginListItem
+        :param OptPluginList: 非广告插件结果列表(SDK、风险插件等)
+        :type OptPluginList: list of OptPluginListItem
+        :param SafeType: 数字类型，分别为0-未知， 1-安全软件，2-风险软件，3-病毒软件
+        :type SafeType: str
+        :param Sid: Session id，合作方可以用来区分回调数据，需要唯一。
+        :type Sid: str
+        :param SoftName: 安装包名称
+        :type SoftName: str
+        :param Spot: 插播广告软件标记，取值：-1 不确定，0否， 1 是
+        :type Spot: str
+        :param VirusName: 病毒名称，utf8编码
+        :type VirusName: str
+        :param VirusDesc: 病毒描述，utf8编码
+        :type VirusDesc: str
+        :param RepackageStatus: 二次打包状态：0-表示默认；1-表示二次
+        :type RepackageStatus: str
+        :param Errno: 应用错误码：0、1-表示正常；                  
+
+2表示System Error(engine analysis error).
+
+3表示App analysis error, please confirm it.
+
+4表示App have not cert, please confirm it.
+
+5表示App size is zero, please confirm it.
+
+6表示App have not package name, please confirm it.
+
+7表示App build time is empty, please confirm it.
+
+8表示App have not valid cert, please confirm it.
+
+99表示Other error.
+
+1000表示App downloadlink download fail, please confirm it.
+
+1001表示APP md5 different between real md5, please confirm it.
+
+1002表示App md5 uncollect, please offer downloadlink.
+        :type Errno: str
+        :param ErrMsg: 对应errno的错误信息描述
+        :type ErrMsg: str
+        """
+        self.Banner = None
+        self.BoutiqueRecommand = None
+        self.FloatWindows = None
+        self.IntegralWall = None
+        self.Md5 = None
+        self.NotifyBar = None
+        self.Official = None
+        self.PluginList = None
+        self.OptPluginList = None
+        self.SafeType = None
+        self.Sid = None
+        self.SoftName = None
+        self.Spot = None
+        self.VirusName = None
+        self.VirusDesc = None
+        self.RepackageStatus = None
+        self.Errno = None
+        self.ErrMsg = None
+
+
+    def _deserialize(self, params):
+        self.Banner = params.get("Banner")
+        self.BoutiqueRecommand = params.get("BoutiqueRecommand")
+        self.FloatWindows = params.get("FloatWindows")
+        self.IntegralWall = params.get("IntegralWall")
+        self.Md5 = params.get("Md5")
+        self.NotifyBar = params.get("NotifyBar")
+        self.Official = params.get("Official")
+        if params.get("PluginList") is not None:
+            self.PluginList = []
+            for item in params.get("PluginList"):
+                obj = PluginListItem()
+                obj._deserialize(item)
+                self.PluginList.append(obj)
+        if params.get("OptPluginList") is not None:
+            self.OptPluginList = []
+            for item in params.get("OptPluginList"):
+                obj = OptPluginListItem()
+                obj._deserialize(item)
+                self.OptPluginList.append(obj)
+        self.SafeType = params.get("SafeType")
+        self.Sid = params.get("Sid")
+        self.SoftName = params.get("SoftName")
+        self.Spot = params.get("Spot")
+        self.VirusName = params.get("VirusName")
+        self.VirusDesc = params.get("VirusDesc")
+        self.RepackageStatus = params.get("RepackageStatus")
+        self.Errno = params.get("Errno")
+        self.ErrMsg = params.get("ErrMsg")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ScanInfo(AbstractModel):
     """需要扫描的应用的服务信息
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param CallbackUrl: 任务处理完成后的反向通知回调地址,批量提交app每扫描完成一个会通知一次,通知为POST请求，post信息{ItemId:
         :type CallbackUrl: str
         :param ScanTypes: VULSCAN-漏洞扫描信息，VIRUSSCAN-返回病毒扫描信息， ADSCAN-广告扫描信息，PLUGINSCAN-插件扫描信息，PERMISSION-系统权限信息，SENSITIVE-敏感词信息，可以自由组合
@@ -1603,7 +1946,7 @@ class ScanPermissionInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Permission: 系统权限
         :type Permission: str
         """
@@ -1627,7 +1970,7 @@ class ScanPermissionList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PermissionList: 系统权限信息
         :type PermissionList: list of ScanPermissionInfo
         """
@@ -1656,7 +1999,7 @@ class ScanSensitiveInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WordList: 敏感词
         :type WordList: list of str
         :param FilePath: 敏感词对应的文件信息
@@ -1688,7 +2031,7 @@ class ScanSensitiveList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SensitiveList: 敏感词列表
         :type SensitiveList: list of ScanSensitiveInfo
         """
@@ -1717,7 +2060,7 @@ class ScanSetInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskStatus: 任务状态: 1-已完成,2-处理中,3-处理出错,4-处理超时
         :type TaskStatus: int
         :param AppDetailInfo: app信息
@@ -1793,7 +2136,7 @@ class ServiceInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ServiceEdition: 服务版本，基础版basic，专业版professional，企业版enterprise。
         :type ServiceEdition: str
         :param CallbackUrl: 任务处理完成后的反向通知回调地址，如果不需要通知请传递空字符串。通知为POST请求，post包体数据示例{"Response":{"ItemId":"4cdad8fb86f036b06bccb3f58971c306","ShieldCode":0,"ShieldMd5":"78701576793c4a5f04e1c9660de0aa0b","ShieldSize":11997354,"TaskStatus":1,"TaskTime":1539148141}}，调用方需要返回如下信息，{"Result":"ok","Reason":"xxxxx"}，如果Result字段值不等于ok会继续回调。
@@ -1829,7 +2172,7 @@ class ShieldInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ShieldCode: 加固结果的返回码
         :type ShieldCode: int
         :param ShieldSize: 加固后app的大小
@@ -1877,7 +2220,7 @@ class ShieldPlanInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 加固策略数量
         :type TotalCount: int
         :param PlanSet: 加固策略具体信息数组
@@ -1910,7 +2253,7 @@ class SoInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SoFileNames: so文件列表
         :type SoFileNames: list of str
         """
@@ -1934,7 +2277,7 @@ class VirusInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SafeType: 软件安全类型，分别为0-未知、 1-安全软件、2-风险软件、3-病毒软件
         :type SafeType: int
         :param VirusName: 病毒名称， utf8编码，非病毒时值为空
@@ -1966,7 +2309,7 @@ class VulInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param VulList: 漏洞列表
         :type VulList: list of VulList
         :param VulFileScore: 漏洞文件评分
@@ -1999,7 +2342,7 @@ class VulList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param VulId: 漏洞id
         :type VulId: str
         :param VulName: 漏洞名称
